@@ -13,7 +13,7 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
-(* $Id: chasen.ml 132 2005-08-07 18:05:59Z yori $ *)
+(* $Id: chasen.ml 143 2005-08-21 12:29:43Z yori $ *)
 
 type darts
 type mrph_prim
@@ -331,3 +331,32 @@ let new_word ~kaki ~yomi  =
       create_undefword yomi kaki mrph_default_weight no :: !mrph_list
   done;
   !mrph_list
+
+let null_mrph =
+  `Mrph_data (new_mrph_data
+		~posid:0
+		~inf_type:0
+		~inf_form:0
+		~weight:0
+		~con_tbl:0
+		~keyword:""
+		~headword:""
+		~reading:""
+		~pron:""
+		~stem_len:0
+		~base:""
+		~info:""
+		~compound:0
+		~is_undef:0
+		(* FIXME *)
+		~dat_index:0
+		~darts:(Obj.magic 0))
+
+let compare_mrph m1 m2 =
+  let sgn = posid m1 - posid m2 in
+  if sgn <> 0 then sgn else
+  let d1 = mrph_data_of_mrph m1 in
+  let d2 = mrph_data_of_mrph m2 in
+  Pervasives.compare
+    (surface_form d1)
+    (surface_form d2)
