@@ -13,7 +13,7 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
-(* $Id: chasen.mli 132 2005-08-07 18:05:59Z yori $ *)
+(* $Id: chasen.mli 143 2005-08-21 12:29:43Z yori $ *)
 
 external romaji : string -> string = "caml_romaji"
 external katakana : string -> string = "caml_katakana"
@@ -74,3 +74,6 @@ val serialize_mrph : mrph -> string
 val deserialize_mrph : string -> mrph
 
 val new_word : kaki:string -> yomi:string -> mrph list
+
+val null_mrph : mrph
+val compare_mrph : mrph -> mrph -> int
