@@ -13,7 +13,7 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
-(* $Id: parse.mli 132 2005-08-07 18:05:59Z yori $ *)
+(* $Id: parse.mli 144 2005-08-21 12:32:00Z yori $ *)
 
 (** ʸĹʸΰ֤EUCʸοɽ롣*)
 
@@ -28,8 +28,9 @@ val parse : string -> state:int -> pos:int -> len:int -> parse_obj
 ǺŬʥΡɤؤΥѥȺǽ֤ȥȤȤ֤ѥ[(mrph, p,
 l, state, cost)]ΥꥹȤȤɽ졢[p]ʸΰ֡[l]б
 ʬʸĹ[state][mrph]Ϣܤľξ֡[cost]
-[mrph]ޤ᤿[mrph]ޤǤȡ*)
-val best_path : parse_obj -> int -> 
+[mrph]ޤ᤿[mrph]ޤǤȡѥʤ㳰[Not_found]
+ȯ*)
+val best_path : parse_obj -> 
   (Chasen.mrph * int * int * int * int) list
 
 (** [list_candidates string state pos mrph_len len][state]ȯ
